@@ -24,7 +24,12 @@ from .plot.ad.engagement.viz import (
     plotAdsCountGroupedByAdvertiserNames,
     plotAdsCountGroupedByEngagementTypes,
     plotTopXAdvertisersAsHeatMap,
-    plotTargetCriteriasForTopXAdvertisers
+    plotTargetCriteriasForTopXAdvertisers,
+    plotTopXTargetCriteriasUsedByTwitterAdvertisers,
+    plotBarChartShowingAdTargetCriteriaUsageCountGroupedByType,
+    plotTopXHashTagsInPromotedTweets,
+    plotTopXHashTagsUsedByTopYAdvertisersInPromotedTweets,
+    plotTopXTaggedAccountsInPromotedTweets
 )
 from time import time
 
@@ -47,7 +52,7 @@ def _calculateSuccess(_data: List[bool]) -> float:
 
 
 def _banner():
-    print('\x1b[1;6;36;49m[+]twiz v0.2.5 - Your Twitter Account Data Analysis & Visualization Tool <3\x1b[0m\n\n\t\x1b[3;39;40m$ twiz `path-to-zip-file` `path-to-sink-directory`\x1b[0m\n\n[+]Author: Anjan Roy <anjanroy@yandex.com>\n[+]Source: https://github.com/itzmeanjan/twiz ( CC0-1.0 Licensed )\n')
+    print('\x1b[1;6;36;49m[+]twiz v0.3.0 - Your Twitter Account Data Analysis & Visualization Tool <3\x1b[0m\n\n\t\x1b[3;39;40m$ twiz `path-to-zip-file` `path-to-sink-directory`\x1b[0m\n\n[+]Author: Anjan Roy <anjanroy@yandex.com>\n[+]Source: https://github.com/itzmeanjan/twiz ( CC0-1.0 Licensed )\n')
 
 
 def _joinName(name: str) -> str:
@@ -164,7 +169,29 @@ def main():
                 _engagements,
                 5,
                 f'Twitter Ad Targeting Criterias used for {_accountDisplayName} by ',
-                f'plots/twitterAdTargetingCriteriasUsedFor{_joinName(_accountDisplayName)}By')
+                f'plots/twitterAdTargetingCriteriasUsedFor{_joinName(_accountDisplayName)}By'),
+            plotTopXTargetCriteriasUsedByTwitterAdvertisers(
+                _engagements,
+                20,
+                f'Top 20 Ad Target Criterias used for {_accountDisplayName} on Twitter',
+                f'plots/top20AdTargetCriteriasUsedFor{_joinName(_accountDisplayName)}OnTwitter.png'),
+            plotBarChartShowingAdTargetCriteriaUsageCountGroupedByType(
+                _engagements,
+                _accountDisplayName),
+            plotTopXHashTagsInPromotedTweets(
+                _engagements,
+                20,
+                f'Top 20 #HashTags in Promoted Tweets targeting {_accountDisplayName}',
+                f'plots/top20HashTagsInPromotedTweetsFor{_joinName(_accountDisplayName)}.png'),
+            plotTopXHashTagsUsedByTopYAdvertisersInPromotedTweets(
+                _engagements, 3, 10,
+                f'Top 3 #HashTags in Tweets promoted by top 10 Advertisers',
+                f'plots/top3HashTagsInPromotedTweetsFromTop10AdvertisersFor{_joinName(_accountDisplayName)}.png'),
+            plotTopXTaggedAccountsInPromotedTweets(
+                _engagements,
+                20,
+                f'Top 20 @TaggedUsers in Promoted Tweets targeting {_accountDisplayName}',
+                f'plots/top20TaggedUsersInPromotedTweetsFor{_joinName(_accountDisplayName)}.png')
         ]
 
         print('[+]Obtained success : {:.2f} %, in {:.2f} s'.format(
